# Changelog

All notable changes to this project will be documented in this file.

## [0.1.0] - 2026-03-17

- Initial public release.
- Added compact C implementation of Recursive Group Coding.
- Added Python wrapper for the C implementation.
- Added minimalist C and Python demos.
